==> tecfy_corev2_package-1.1.51.tar.gz: lib/views/report/report_list.page.dart <==
part of tecfy_corev2_client_package;

class ReportListPage extends StatefulWidget {
  @override
  _ReportListPageState createState() => _ReportListPageState();
}

class _ReportListPageState extends State<ReportListPage> {
  List<dynamic>? _reports;

  @override
  void initState() {
    _getData();
    super.initState();
  }

  _getData() async {
    var result =
        await TecfyBasicApp.apiService.httpGetDynamic('Report/GetList');
    if (result.success) {
      if (TecfyBasicApp.isNewer(result.lastVersion)) {
        AppNavigator.navigateTo(context, () => UpgradePage(isRequired: false));
      }
      setState(() {
        _reports = result.data;
      });
    }
  }

  _onPressed(report) async {
    await ReportDataService.onOpenReport(context, report);
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(
      context,
      'Reports',
      'report',
      isMobile: LayoutService.isMobile(context),
      child: _reports == null
          ? Center(child: AppNavigator.getLoadingWidget(100))
          : ListView(
              children: _reports
                      ?.map<Widget>(
                        (report) => Container(
                          alignment: Alignment.center,
                          child: Container(
                            height: 50,
                            constraints: BoxConstraints(maxWidth: 300),
                            padding: EdgeInsets.all(5),
                            child: MaterialButton(
                              shape: RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(5)),
                              padding: EdgeInsets.all(5),
                              color: ThemeService.mainColor,
                              onPressed: () => _onPressed(report),
                              child: Row(
                                mainAxisAlignment: MainAxisAlignment.start,
                                children: <Widget>[
                                  SizedBox(width: 5),
                                  // isBussy
                                  //     ? Transform.scale(
                                  //         scale: 0.5,
                                  //         child: CircularProgressIndicator(
                                  //           valueColor: AlwaysStoppedAnimation<Color>(
                                  //               ThemeService.textOnMainColor),
                                  //         ))
                                  //     :
                                  Transform.scale(
                                      scale: 0.8,
                                      child: Icon(Icons.print,
                                          color: Colors.white)),
                                  SizedBox(width: 5),
                                  Text(
                                    report['name${LocalConfigService.languagePrefix}'] ??
                                        'N/A',
                                    style: TextStyle(
                                        color: ThemeService.textOnMainColor),
                                  )
                                ],
                              ),
                            ),
                          ),
                        ),
                      )
                      .toList() ??
                  [],
            ),
    );
  }
}

==> tecfy_corev2_package-1.1.78.tar.gz: lib/views/report/report_list.page.dart <==
part of tecfy_corev2_client_package;

class ReportListPage extends StatefulWidget {
  @override
  _ReportListPageState createState() => _ReportListPageState();
}

class _ReportListPageState extends State<ReportListPage> {
  List<dynamic>? _reports;

  @override
  void initState() {
    _getData();
    super.initState();
  }

  _getData() async {
    var result = await TecfyBasicApp.apiService
        .httpGetDynamic('admin/setup/Report/GetList');
    if (result.success) {
      if (TecfyBasicApp.isNewer(result.lastVersion)) {
        AppNavigator.navigateTo(context, () => UpgradePage(isRequired: false));
      }
      setState(() {
        _reports = result.data;
      });
    }
  }

  _onPressed(report) async {
    await ReportDataService.onOpenReport(context, report);
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(
      context,
      'Reports',
      'report',
      isMobile: LayoutService.isMobile(context),
      child: _reports == null
          ? Center(child: AppNavigator.getLoadingWidget(100))
          : ListView(
              children: _reports
                      ?.map<Widget>(
                        (report) => Container(
                          alignment: Alignment.center,
                          child: Container(
                            height: 50,
                            constraints: BoxConstraints(maxWidth: 300),
                            padding: EdgeInsets.all(5),
                            child: MaterialButton(
                              shape: RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(5)),
                              padding: EdgeInsets.all(5),
                              color: ThemeService.mainColor,
                              onPressed: () => _onPressed(report),
                              child: Row(
                                mainAxisAlignment: MainAxisAlignment.start,
                                children: <Widget>[
                                  SizedBox(width: 5),
                                  // isBussy
                                  //     ? Transform.scale(
                                  //         scale: 0.5,
                                  //         child: CircularProgressIndicator(
                                  //           valueColor: AlwaysStoppedAnimation<Color>(
                                  //               ThemeService.textOnMainColor),
                                  //         ))
                                  //     :
                                  Transform.scale(
                                      scale: 0.8,
                                      child: Icon(Icons.print,
                                          color: Colors.white)),
                                  SizedBox(width: 5),
                                  Text(
                                    (MapService.getValue(report, 'name')
                                                as Map<String, dynamic>)[
                                            LocalConfigService.languagePrefix
                                                .toLowerCase()] ??
                                        'N/A',
                                    style: TextStyle(
                                        color: ThemeService.textOnMainColor),
                                  ),
                                ],
                              ),
                            ),
                          ),
                        ),
                      )
                      .toList() ??
                  [],
            ),
    );
  }
}
